@@ -22,6 +22,8 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Browser;
 
 internal sealed class CloseCommand()
-    : Command<Parameters, EmptyResult>(Parameters.Empty, "browser.close");
+    : Command<Parameters, CloseResult>(Parameters.Empty, "browser.close");
 
 public sealed class CloseOptions : CommandOptions;
+
+public sealed record CloseResult : EmptyResult;
