@@ -18,6 +18,8 @@
 // </copyright>
 
 using OpenQA.Selenium.BiDi.Communication;
+using OpenQA.Selenium.BiDi.Communication.Json.Converters;
+using System.Text.Json.Serialization;
 
 namespace OpenQA.Selenium.BiDi.BrowsingContext;
 
@@ -35,6 +37,7 @@ public sealed class CreateOptions : CommandOptions
     public Browser.UserContext? UserContext { get; set; }
 }
 
+[JsonConverter(typeof(CamelCaseEnumConverter<ContextType>))]
 public enum ContextType
 {
     Tab,
