@@ -22,7 +22,7 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.BrowsingContext;
 
 internal sealed class HandleUserPromptCommand(HandleUserPromptParameters @params)
-    : Command<HandleUserPromptParameters, EmptyResult>(@params, "browsingContext.handleUserPrompt");
+    : Command<HandleUserPromptParameters, HandleUserPromptResult>(@params, "browsingContext.handleUserPrompt");
 
 internal sealed record HandleUserPromptParameters(BrowsingContext Context, bool? Accept, string? UserText) : Parameters;
 
@@ -32,3 +32,5 @@ public sealed class HandleUserPromptOptions : CommandOptions
 
     public string? UserText { get; set; }
 }
+
+public sealed record HandleUserPromptResult : EmptyResult;
