@@ -18,7 +18,6 @@
 // </copyright>
 
 using OpenQA.Selenium.BiDi.Communication;
-using System.Collections;
 using System.Collections.Generic;
 
 namespace OpenQA.Selenium.BiDi.BrowsingContext;
@@ -37,20 +36,4 @@ public sealed class LocateNodesOptions : CommandOptions
     public IEnumerable<Script.ISharedReference>? StartNodes { get; set; }
 }
 
-public sealed record LocateNodesResult : EmptyResult, IReadOnlyList<Script.NodeRemoteValue>
-{
-    internal LocateNodesResult(IReadOnlyList<Script.NodeRemoteValue> nodes)
-    {
-        Nodes = nodes;
-    }
-
-    public IReadOnlyList<Script.NodeRemoteValue> Nodes { get; }
-
-    public Script.NodeRemoteValue this[int index] => Nodes[index];
-
-    public int Count => Nodes.Count;
-
-    public IEnumerator<Script.NodeRemoteValue> GetEnumerator() => Nodes.GetEnumerator();
-
-    IEnumerator IEnumerable.GetEnumerator() => (Nodes as IEnumerable).GetEnumerator();
-}
+public sealed record LocateNodesResult(IReadOnlyList<Script.NodeRemoteValue> Nodes) : EmptyResult;
