@@ -22,7 +22,7 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.BrowsingContext;
 
 internal sealed class SetViewportCommand(SetViewportParameters @params)
-    : Command<SetViewportParameters, EmptyResult>(@params, "browsingContext.setViewport");
+    : Command<SetViewportParameters, SetViewportResult>(@params, "browsingContext.setViewport");
 
 internal sealed record SetViewportParameters(BrowsingContext Context, Viewport? Viewport, double? DevicePixelRatio) : Parameters;
 
@@ -34,3 +34,5 @@ public sealed class SetViewportOptions : CommandOptions
 }
 
 public readonly record struct Viewport(long Width, long Height);
+
+public sealed record SetViewportResult : EmptyResult;
