@@ -22,8 +22,10 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Network;
 
 internal sealed class RemoveInterceptCommand(RemoveInterceptParameters @params)
-    : Command<RemoveInterceptParameters, EmptyResult>(@params, "network.removeIntercept");
+    : Command<RemoveInterceptParameters, RemoveInterceptResult>(@params, "network.removeIntercept");
 
 internal sealed record RemoveInterceptParameters(Intercept Intercept) : Parameters;
 
 public class RemoveInterceptOptions : CommandOptions;
+
+public sealed record RemoveInterceptResult : EmptyResult;
