@@ -22,6 +22,8 @@ using OpenQA.Selenium.BiDi.Communication;
 namespace OpenQA.Selenium.BiDi.Session;
 
 internal sealed class EndCommand()
-    : Command<Parameters, EmptyResult>(Parameters.Empty, "session.end");
+    : Command<Parameters, EndResult>(Parameters.Empty, "session.end");
 
 public sealed class EndOptions : CommandOptions;
+
+public sealed record EndResult : EmptyResult;
