@@ -17,16 +17,15 @@
 // under the License.
 // </copyright>
 
-namespace OpenQA.Selenium
+namespace OpenQA.Selenium;
+
+/// <summary>
+/// Defines the interface through which the user can determine the capabilities of a driver.
+/// </summary>
+public interface IHasCapabilities
 {
     /// <summary>
-    /// Defines the interface through which the user can determine the capabilities of a driver.
+    /// Gets the <see cref="ICapabilities"/> object describing the driver's capabilities.
     /// </summary>
-    public interface IHasCapabilities
-    {
-        /// <summary>
-        /// Gets the <see cref="ICapabilities"/> object describing the driver's capabilities.
-        /// </summary>
-        ICapabilities Capabilities { get; }
-    }
+    ICapabilities Capabilities { get; }
 }
