@@ -17,17 +17,16 @@
 // under the License.
 // </copyright>
 
-namespace OpenQA.Selenium
+namespace OpenQA.Selenium;
+
+/// <summary>
+/// Defines the interface used to take screen shot images of the screen.
+/// </summary>
+public interface ITakesScreenshot
 {
     /// <summary>
-    /// Defines the interface used to take screen shot images of the screen.
+    /// Gets a <see cref="Screenshot"/> object representing the image of the page on the screen.
     /// </summary>
-    public interface ITakesScreenshot
-    {
-        /// <summary>
-        /// Gets a <see cref="Screenshot"/> object representing the image of the page on the screen.
-        /// </summary>
-        /// <returns>A <see cref="Screenshot"/> object containing the image.</returns>
-        Screenshot GetScreenshot();
-    }
+    /// <returns>A <see cref="Screenshot"/> object containing the image.</returns>
+    Screenshot GetScreenshot();
 }
