@@ -440,31 +440,37 @@ public class HttpCommandExecutor : ICommandExecutor
         /// <returns>The http response message content.</returns>
         protected override async Task<HttpResponseMessage> SendAsync(HttpRequestMessage request, CancellationToken cancellationToken)
         {
-            var responseTask = base.SendAsync(request, cancellationToken);
-
             StringBuilder requestLogMessageBuilder = new();
-            requestLogMessageBuilder.AppendFormat(">> {0} RequestUri: {1}, Content: {2}, Headers: {3}",
+            requestLogMessageBuilder.AppendFormat(">> {0} {1}",
                 request.Method,
-                request.RequestUri?.ToString() ?? "null",
-                request.Content?.ToString() ?? "null",
-                request.Headers?.Count());
+                request.RequestUri?.ToString() ?? "null");
 
-            if (request.Content != null)
+            if (request.Content is not null)
             {
+#if NET8_0_OR_GREATER
+                var requestContent = await request.Content.ReadAsStringAsync(cancellationToken).ConfigureAwait(false);
+#else
                 var requestContent = await request.Content.ReadAsStringAsync().ConfigureAwait(false);
+#endif
                 requestLogMessageBuilder.AppendFormat("{0}{1}", Environment.NewLine, requestContent);
             }
 
             _logger.Trace(requestLogMessageBuilder.ToString());
 
-            var response = await responseTask.ConfigureAwait(false);
+            var response = await base.SendAsync(request, cancellationToken).ConfigureAwait(false);
 
             StringBuilder responseLogMessageBuilder = new();
-            responseLogMessageBuilder.AppendFormat("<< StatusCode: {0}, ReasonPhrase: {1}, Content: {2}, Headers: {3}", (int)response.StatusCode, response.ReasonPhrase, response.Content, response.Headers?.Count());
+
+            responseLogMessageBuilder.AppendFormat("<< {0} {1}", (int)response.StatusCode, response.ReasonPhrase);
 
             if (!response.IsSuccessStatusCode && response.Content != null)
             {
+#if NET8_0_OR_GREATER
+                var responseContent = await response.Content.ReadAsStringAsync(cancellationToken).ConfigureAwait(false);
+#else
                 var responseContent = await response.Content.ReadAsStringAsync().ConfigureAwait(false);
+#endif
+
                 responseLogMessageBuilder.AppendFormat("{0}{1}", Environment.NewLine, responseContent);
             }
 
