@@ -201,7 +201,7 @@ class StorageCommandsTest extends JupiterTestBase {
     BytesValue value = new BytesValue(BytesValue.Type.STRING, "cod");
     String domain = appServer.getHostName();
 
-    long expiry = Instant.now().toEpochMilli() + 3600 * 1000;
+    long expiry = Instant.now().getEpochSecond() + 3600;
 
     String path = "/common/animals";
 
@@ -257,8 +257,8 @@ class StorageCommandsTest extends JupiterTestBase {
     assertThat(key.getUserContext()).isEqualTo("default");
   }
 
-  @Test
   @NotYetImplemented(EDGE)
+  @Test
   public void canGetAllCookies() {
     String key1 = generateUniqueKey();
     String key2 = generateUniqueKey();
