@@ -57,6 +57,12 @@ def test_execute_custom_command(mock_request, remote_connection):
     assert response == {"status": 200, "value": "OK"}
 
 
+def test_default_websocket_settings():
+    config = ClientConfig(remote_server_addr="http://localhost:4444")
+    assert config.websocket_timeout == 30.0
+    assert config.websocket_interval == 0.1
+
+
 def test_get_remote_connection_headers_defaults():
     url = "http://remote"
     headers = RemoteConnection.get_remote_connection_headers(parse.urlparse(url))
@@ -65,7 +71,7 @@ def test_get_remote_connection_headers_defaults():
     assert headers.get("Accept") == "application/json"
     assert headers.get("Content-Type") == "application/json;charset=UTF-8"
     assert headers.get("User-Agent").startswith(f"selenium/{__version__} (python ")
-    assert headers.get("User-Agent").split(" ")[-1] in {"windows)", "mac)", "linux)", "mac", "windows", "linux"}
+    assert headers.get("User-Agent").split(" ")[-1].rstrip(")") in ("win32", "windows", "mac", "linux")
 
 
 def test_get_remote_connection_headers_adds_auth_header_if_pass(recwarn):
